pub struct OmenaQueryExpressionDomainFlowRuntimeV0 { /* private fields */ }Implementations
Sourceimpl OmenaQueryExpressionDomainFlowRuntimeV0
impl OmenaQueryExpressionDomainFlowRuntimeV0
pub fn revision(&self) -> u64
pub fn graph_count(&self) -> usize
Sourcepub fn read_set_digest_check_count(&self) -> usize
pub fn read_set_digest_check_count(&self) -> usize
Number of sealed read-set digest checks performed by the product runtime across all revisions.
Sourcepub fn analysis_rebuild_count(&self) -> usize
pub fn analysis_rebuild_count(&self) -> usize
Number of analyses rebuilt by the product runtime across all revisions.
Sourcepub fn artifact_refusal_count(&self) -> usize
pub fn artifact_refusal_count(&self) -> usize
Number of internally retained artifacts refused before a safe rebuild.
pub fn analyze_input( &mut self, input: &EngineInputV2, ) -> OmenaQueryExpressionDomainIncrementalFlowAnalysisV0